@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 from __future__ import with_statement
 
@@ -94,7 +98,7 @@ def cmd_executor(cmd):
             else:
                 cmd = cmd.encode("utf8") if isinstance(cmd,unicode) else cmd
                 log_debug("Executing command: %s\n" % cmd)
-            p1 = subprocess.Popen(cmd, stdout=subprocess.PIPE, stdin=subprocess.PIPE, stderr=subprocess.PIPE, startupinfo=info, shell = True)
+            p1 = subprocess.Popen(str(cmd), stdout=subprocess.PIPE, stdin=subprocess.PIPE, stderr=subprocess.PIPE, startupinfo=info, shell = True)
         except OSError, exc:
             log_error("Error executing command %s\n%s\n" % (cmd, exc))
             import traceback
@@ -193,7 +197,6 @@ class SpatialImporter:
                      
     def run(self, progress_notify):
         cmd_args = {}
-        cmd_args['ogr2ogr'] = get_exe_path("ogr2ogr")
         cmd_args['host'] = self.my_host
         cmd_args['schema'] = self.my_schema
         cmd_args['user'] = self.my_user
@@ -201,8 +204,9 @@ class SpatialImporter:
         cmd_args['port'] = self.my_port
         
         cmd = []
-        cmd.append("exec")
-        cmd.append(get_exe_path("ogr2ogr"))
+        if sys.platform.lower() != "win32":
+            cmd.append("exec")
+        cmd.append(get_exe_path("ogr2ogr.exe" if sys.platform.lower() == "win32" else "ogr2ogr"))
         cmd.append("-f")
         cmd.append('"MySQL"')
         cmd.append('MySQL:"%(schema)s,host=%(host)s,user=%(user)s,password=%(pwd)s,port=%(port)d"' % cmd_args)
@@ -284,14 +288,14 @@ class SelectFileWizardPage(WizardPage):
         self.shapefile_browse_btn = newButton()
         self.shapefile_browse_btn.set_text("Browse...")
         self.shapefile_browse_btn.add_clicked_callback(self.shapefile_browse)
-        entry_box.add(self.shapefile_browse_btn, False, False)
+        entry_box.add(self.shapefile_browse_btn, False, True)
 
         self.content.add(entry_box, False, True)
 
         label = mforms.newLabel("""Select a shapefile containing spatial data to load into MySQL.
 A new table with the imported fields will be created in the selected schema,
 unless the append or update options are specified.""")
-        self.content.add(label, False, False)
+        self.content.add(label, False, True)
 
         self.ogrinfo_box = mforms.newBox(True)
         self.ogrinfo_box.set_spacing(8)
@@ -344,19 +348,19 @@ unless the append or update options are specified.""")
         
         self.warning_srs = mforms.newLabel("")
         self.content.add(self.warning_srs, False, True)
+        self.check_ogr_executables()
 
     def go_cancel(self):
         self.main.cancel()
 
     def check_ogr_executables(self):
-        if get_exe_path("ogrinfo"):
+        if get_exe_path("ogrinfo.exe" if sys.platform.lower() == "win32" else "ogrinfo"):
             self.ogrinfo_missing = False
             self.ogrinfo_icon.set_image("task_checked%s.png" % os_icon_suffix)
         else:
             self.ogrinfo_icon.set_image("task_warning%s.png" % os_icon_suffix)
             self.ogrinfo_missing_lbl.show(True)
-
-        if get_exe_path("ogr2ogr"):
+        if get_exe_path("ogr2ogr.exe" if sys.platform.lower() == "win32" else "ogr2ogr"):
             self.ogr2ogr_missing = False
             self.ogr2ogr_icon.set_image("task_checked%s.png" % os_icon_suffix)
         else:
@@ -364,7 +368,6 @@ unless the append or update options are specified.""")
             self.ogr2ogr_missing_lbl.show(True)
 
     def validate(self):
-        self.check_ogr_executables()
         if self.ogrinfo_missing or self.ogr2ogr_missing:
             mforms.Utilities.show_error("Missing Executable", "One of the required executables is missing. Please correct this before continue.", "OK", "", "")
             return False
@@ -411,9 +414,9 @@ class ContentPreviewPage(WizardPage):
         return self.main.select_file_page.shapefile_path.get_string_value()
     
     def get_info(self):
-        cmd = "%s -al -so %s" % (get_exe_path("ogrinfo"), self.get_path())
+        cmd = "%s -al -so %s" % (get_exe_path("ogrinfo.exe" if sys.platform.lower() == "win32" else "ogrinfo"), self.get_path())
         p1 = cmd_executor(cmd)
-        sout, serr = p1.communicate(input)
+        sout, serr = p1.communicate()
         if serr:
             log_error("There was an error getting file information: %s" % serr)
         import re
@@ -477,18 +480,18 @@ class ContentPreviewPage(WizardPage):
         layer_box = mforms.newBox(True)
         layer_box.set_spacing(8)
         layer_heading = mforms.newLabel("Layer name:")
-        layer_box.add(layer_heading, False, False)
+        layer_box.add(layer_heading, False, True)
         self.layer_name_lbl = mforms.newLabel("")
-        layer_box.add(self.layer_name_lbl, False, False)
-        self.content.add(layer_box, False, False)
+        layer_box.add(self.layer_name_lbl, False, True)
+        self.content.add(layer_box, False, True)
 
         epsg_box = mforms.newBox(True)
         epsg_box.set_spacing(8)
         epsg_box_heading = mforms.newLabel("EPSG:")
-        epsg_box.add(epsg_box_heading, False, False)
+        epsg_box.add(epsg_box_heading, False, True)
         self.epsg_lbl = mforms.newLabel("")
-        epsg_box.add(self.epsg_lbl, False, False)
-        self.content.add(epsg_box, False, False)
+        epsg_box.add(self.epsg_lbl, False, True)
+        self.content.add(epsg_box, False, True)
         
         entry_box = mforms.newBox(True)
         entry_box.set_spacing(12)
@@ -528,18 +531,18 @@ class ContentPreviewPage(WizardPage):
         self.skipfailures_chb.set_text("Skip failures");
         self.skipfailures_chb.set_active(False)
         
-        boxfailures.add(self.skipfailures_chb, False, False)
-        boxfailures.add(small_label("If an error occurs ignore it and continue processing data."), False, False)
-        options_box.add(boxfailures, False, False)
+        boxfailures.add(self.skipfailures_chb, False, True)
+        boxfailures.add(small_label("If an error occurs ignore it and continue processing data."), False, True)
+        options_box.add(boxfailures, False, True)
         
         boxappend = mforms.newBox(False)
         
         self.append_chb = newCheckBox()
         self.append_chb.set_text("Append to existing data");
         self.append_chb.set_active(False)
-        boxappend.add(self.append_chb, False, False)
-        boxappend.add(small_label("Append to existing table instead of creating a new one."), False, False)
-        options_box.add(boxappend, False, False)
+        boxappend.add(self.append_chb, False, True)
+        boxappend.add(small_label("Append to existing table instead of creating a new one."), False, True)
+        options_box.add(boxappend, False, True)
         
         boxoverwrite = mforms.newBox(False)
         
@@ -549,30 +552,30 @@ class ContentPreviewPage(WizardPage):
         
         self.append_chb.add_clicked_callback(lambda checkbox1 = self.append_chb, checkbox2 = self.overwrite_chb: self.one_check_only(checkbox1, checkbox2))
         self.overwrite_chb.add_clicked_callback(lambda checkbox2 = self.append_chb, checkbox1 = self.overwrite_chb: self.one_check_only(checkbox1, checkbox2))
-        boxoverwrite.add(self.overwrite_chb, False, False)
-        boxoverwrite.add(small_label("Drop the selected table and recreate it."), False, False)
-        options_box.add(boxoverwrite, False, False)
+        boxoverwrite.add(self.overwrite_chb, False, True)
+        boxoverwrite.add(small_label("Drop the selected table and recreate it."), False, True)
+        options_box.add(boxoverwrite, False, True)
         
         if self.support_spatial_index:
             boxspatial = mforms.newBox(False)
             self.spatial_index_chb = newCheckBox()
             self.spatial_index_chb.set_text("Create spatial index")
             self.spatial_index_chb.set_active(False)
-            boxspatial.add(self.spatial_index_chb, False, False)
-            boxspatial.add(small_label("import will make spatial index around geometry column"), False, False)
-            options_box.add(boxspatial, False, False)
+            boxspatial.add(self.spatial_index_chb, False, True)
+            boxspatial.add(small_label("import will make spatial index around geometry column"), False, True)
+            options_box.add(boxspatial, False, True)
         
         options_layer.add(options_box)
         options_layer.show(True)
         
-        self.content.add(options_layer, False, False)
+        self.content.add(options_layer, False, True)
 
         boxconvert = mforms.newBox(False)
         entry_box = mforms.newBox(True)
         entry_box.set_spacing(8)
         entry_box.add(mforms.newLabel("Convert data to the following EPSG:"), False, True)
         self.convert_to_epsg = mforms.newTextEntry()
-        entry_box.add(self.convert_to_epsg, False, False)
+        entry_box.add(self.convert_to_epsg, False, True)
         boxconvert.add(entry_box, True, True)
         boxconvert.add(small_label("leave empty to import the data with no conversion"), False, False)
         
