@@ -1,19 +1,23 @@
-# Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 from __future__ import with_statement
 
@@ -34,6 +38,8 @@ from workbench.utils import Version
 
 from workbench.log import log_error, log_info
 
+from wb_common import to_unicode
+
 last_location = ""
 drop_table = False
 truncate_table = False
@@ -53,13 +59,13 @@ def handleContextMenu(name, sender, args):
     
     for s in selection:
         if s.type == 'db.Schema':
-            user_selection = {'schema': s.name, 'table': None}
+            user_selection = {'schema': to_unicode(s.name), 'table': None}
             break
         elif s.type == 'db.Table':
-            user_selection = {'table': s.name, 'schema': s.schemaName}
+            user_selection = {'table': to_unicode(s.name), 'schema': to_unicode(s.schemaName)}
             break
         elif s.type == 'tables':
-            user_selection = {'table': None, 'schema': s.schemaName}
+            user_selection = {'table': None, 'schema': to_unicode(s.schemaName)}
             break
         else:
             return
@@ -85,12 +91,13 @@ class ResultsPage(WizardPage):
     def create_ui(self):
         if self.main.import_progress_page.import_time:
             itime = float("%d.%d" % (self.main.import_progress_page.import_time.seconds, self.main.import_progress_page.import_time.microseconds))
-            self.content.add(mforms.newLabel(str("File %s was imported in %.3f s" % (self.get_path(), itime))), False, True)
+            text = u"File %s was imported in %.3f s" % (self.get_path(), itime)
+            self.content.add(mforms.newLabel(text.encode('utf-8')), False, True)
         
-        
-        self.content.add(mforms.newLabel(str("Table %s.%s %s" % (self.main.destination_table['schema'], 
+        text = u"Table %s.%s %s" % (self.main.destination_table['schema'], 
                                                                  self.main.destination_table['table'], 
-                                                                 "has been used" if self.main.destination_page.existing_table_radio.get_active() else "was created"))), False, True)
+                                                                 "has been used" if self.main.destination_page.existing_table_radio.get_active() else "was created")
+        self.content.add(mforms.newLabel(text.encode('utf-8')), False, True)
         self.content.add(mforms.newLabel(str("%d records imported" % self.main.import_progress_page.module.item_count)), False, True)
 
 class ImportProgressPage(WizardProgressPage):
@@ -186,6 +193,7 @@ class ConfigurationPage(WizardPage):
         format_box.add(mforms.newLabel("Detected file format: %s" % self.input_file_type), False, True)
         if len(self.active_module.options) != 0:
             advanced_opts_btn = mforms.newButton(mforms.ToolButton)
+            advanced_opts_btn.set_size(-1, 16)
             advanced_opts_btn.set_icon(mforms.App.get().get_resource_path("admin_option_file.png"))
             advanced_opts_btn.add_clicked_callback(lambda: self.optpanel.show(False) if self.optpanel.is_shown() else self.optpanel.show(True) )
             format_box.add(advanced_opts_btn, False, True)
@@ -315,16 +323,16 @@ class ConfigurationPage(WizardPage):
         
     def load_dest_columns(self):
         try:
-            rset = self.main.editor.executeManagementQuery("SHOW COLUMNS FROM `%s`.`%s`" % (self.main.destination_table['schema'], self.main.destination_table['table']), 1)
+            rset = self.main.editor.executeManagementQuery(u"SHOW COLUMNS FROM `%s`.`%s`" % (self.main.destination_table['schema'], self.main.destination_table['table']), 1)
         except Exception, e:
-            log_error("SHOW COLUMNS FROM `%s`.`%s` : %s" % (self.main.destination_table['schema'], self.main.destination_table['table'], e))
+            log_error(u"SHOW COLUMNS FROM `%s`.`%s` : %s" % (self.main.destination_table['schema'], self.main.destination_table['table'], to_unicode(e.message)))
             rset = None
             
         if rset:
             self.dest_cols = []
             ok = rset.goToFirstRow()
             while ok:
-                self.dest_cols.append(rset.stringFieldValueByName("Field"))
+                self.dest_cols.append(to_unicode(rset.stringFieldValueByName("Field")))
                 ok = rset.nextRow()    
     
     def call_create_preview_table(self):
@@ -581,27 +589,28 @@ class SelectDestinationPage(WizardPage):
             self.table_list = {}
             db_list = []
             while ok:
-                dbname = rset.stringFieldValue(0)
+                dbname = to_unicode(rset.stringFieldValue(0))
                 if dbname.strip() in ["mysql", "sys", "information_schema", "fabric", "performance_schema"]:
                     ok = rset.nextRow()
                     continue
                 db_list.append(dbname)
                 ok = rset.nextRow()
             
-            rset = self.main.editor.executeManagementQuery("SHOW FULL TABLES FROM `%s`" % self.main.destination_table['schema'], 0)
+            rset = self.main.editor.executeManagementQuery(u"SHOW FULL TABLES FROM `%s`" % self.main.destination_table['schema'], 0)
             if rset:
                 ok = rset.goToFirstRow()
                 while ok:
                     if rset.stringFieldValue(1) == "BASE TABLE":
-                        table_name = rset.stringFieldValue(0) if not compare_in_lowercase else rset.stringFieldValue(0).lower() 
-                        self.table_list["%s.%s" % (self.main.destination_table['schema'], table_name)] = {'schema': self.main.destination_table['schema'], 'table': table_name} 
+                        table_name = to_unicode(rset.stringFieldValue(0)) if not compare_in_lowercase else to_unicode(rset.stringFieldValue(0)).lower()
+                        full_name = u"%s.%s" % (self.main.destination_table['schema'], table_name)
+                        self.table_list[full_name] = {'schema': self.main.destination_table['schema'], 'table': table_name} 
                         
                     ok = rset.nextRow()
             
             self.destination_table_sel.clear()
             self.destination_table_sel.add_items(self.table_list.keys())
             if self.main.destination_table['schema'] and self.main.destination_table['table']:
-                table_name = "%s.%s" % (self.main.destination_table['schema'], self.main.destination_table['table'])
+                table_name = u"%s.%s" % (self.main.destination_table['schema'], self.main.destination_table['table'])
                 if table_name in self.table_list.keys():
                     self.destination_table_sel.set_selected(self.table_list.keys().index(table_name))
             self.destination_database_sel.clear()
@@ -694,7 +703,7 @@ class SelectDestinationPage(WizardPage):
         return False
     
     def check_if_table_exists(self, schema, table):
-        rset = self.main.editor.executeManagementQuery("SHOW TABLES FROM `%s` like '%s'" % (schema, table), 1)
+        rset = self.main.editor.executeManagementQuery(u"SHOW TABLES FROM `%s` like '%s'" % (schema, table), 1)
         if rset and rset.goToFirstRow():
             return True
         return False
@@ -702,10 +711,10 @@ class SelectDestinationPage(WizardPage):
     def validate(self):
         compare_in_lowercase = self.check_server_lower_case_table_names()
         if self.existing_table_radio.get_active():
-            self.main.destination_table = self.table_list[self.destination_table_sel.get_string_value()]
+            self.main.destination_table = self.table_list[to_unicode(self.destination_table_sel.get_string_value())]
         else:
-            self.main.destination_table['schema'] = self.destination_database_sel.get_string_value()
-            self.main.destination_table['table'] = self.new_table_name.get_string_value().strip()
+            self.main.destination_table['schema'] = to_unicode(self.destination_database_sel.get_string_value())
+            self.main.destination_table['table'] = to_unicode(self.new_table_name.get_string_value()).strip()
             if len(self.main.destination_table['table']) == 0:
                 mforms.Utilities.show_error("Table Import", "You need to specify new table name", "Ok", "", "")
                 return False 
@@ -713,7 +722,7 @@ class SelectDestinationPage(WizardPage):
             if compare_in_lowercase:
                 self.main.destination_table['table'] = self.main.destination_table['table'].lower()
             
-            table_name = "%s.%s" % (self.main.destination_table['schema'], self.main.destination_table['table'])
+            table_name = u"%s.%s" % (self.main.destination_table['schema'], self.main.destination_table['table'])
 
             if not self.drop_table_cb.get_active() and (table_name in self.table_list or self.check_if_table_exists(self.main.destination_table['schema'], self.main.destination_table['table'])):
                 res = mforms.Utilities.show_message("Table Import", "You specified to create a new table, but a table with the same name already exists in the selected schema. Would you like to drop it, or use the existing one and truncate?", "Drop the table", "Use Existing One and Truncate it", "Cancel")
