@@ -1,19 +1,23 @@
-# Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
+#
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-# 
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import re
 import sys
@@ -165,6 +169,8 @@ def restoreConnections():
             previous_instances_conns = set()
             duplicated_instance_count = 0
             for candidate_instance in instances:
+                if candidate_instance.connection is None:
+                    continue 
                 if candidate_instance.connection.__id__ in previous_instances_conns:
                     duplicated_instance_count = duplicated_instance_count + 1
                     continue  # Skip instances whose connections are associated to previously processed instances
@@ -454,13 +460,7 @@ def startCommandLineClientForConnection(conn):
         command = """\\"%s\\" \\"-u%s\\" \\"-h%s\\" -P%i %s -p %s""" % (bundled_client_path, user, host, port, socket, schema)
 
         # call mysql client in a loop until either: 1. it exits with no error, or 2. user exits with Ctrl+C.
-        # This is necessary because if the user enters wrong password, the window closes too quick for the user to see what's going on.
-        subprocess.call([ "/bin/sh", "-c",  # <--- having extra /bin/sh wrapper allows GUI terminal to be launched in background (thus run parallel with workbench)
-            get_linux_terminal_program() + " -e '" +
-                "sh -c \"while :; do %s && break || read -p \\\"Press Enter to retry or Ctrl+C to quit\\\" DUMMY_VAR; done\" " % command
-            + "' &"   # <--- launch GUI terminal and exit (returns to Workbench immediately rather than blocking)
-        ])
-        
+        # This is necessary because if the user enters wrong password, the window closes too quick for the user to see what's going on.        
         my_env = os.environ.copy()
         if (("XDG_SESSION_TYPE" in my_env and my_env["XDG_SESSION_TYPE"] == "wayland") 
           or "WAYLAND_DISPLAY" in my_env) and my_env["GDK_BACKEND"]:
@@ -594,6 +594,7 @@ class CheckForUpdateThread(threading.Thread):
         try:
             import urllib2
             import json
+            urllib2.install_opener(urllib2.build_opener(urllib2.ProxyHandler()))
             self.json = json.load(urllib2.urlopen("http://workbench.mysql.com/current-release")) 
         except Exception, error:
 
